'''
 NAME:                histograms_1_python

 DESCRIPTION:         creates a simple outline histogram from a given set of numbers.

 EXECUTION COMMAND:
                      >>> python histograms_1_python
 
 INPUTS:              file called 'master.xy'
                    
 OUTPUTS:             PDF file: python_plot.pdf

 NOTES:               change the input data. 
                      change the output PDF name.


 AUTHOR:              Tommy LE BLANC
                      Space Telescope Science Institute, USA 
 
 REVISION HISTORY:
                      Written by Tommy LE BLANC, DEC 2012. 

'''
# ------------------------ python code begins here

# Import necessary modules
import numpy as np
import matplotlib.pyplot as plt

# Read input data and calculate number of bins
xref, yref, mag = np.loadtxt('master.xy', usecols = (0, 1, 2), unpack = True)

min_mag, max_mag = np.min(mag), np.max(mag)
binsize = 0.2
num_bins = np.floor((max_mag - min_mag) / binsize)

# Create histogram, figure size in inches
fig, ax = plt.subplots(figsize = (4.724, 4.724))

# Define axes
ax.set_xlabel('Mag')
ax.set_ylabel('Histogram Density')
ax.set_xlim(-17., -6.)
ax.set_ylim(0., 2800.)
for t in ax.get_xticklabels(): t.set_fontsize(8)
for t in ax.get_yticklabels(): t.set_fontsize(8)    

# Draw histogram
ax.hist(mag, num_bins, color='red', lw=2., histtype='step')

# Save plot as a PDF file
fig.savefig('python_plot.pdf')
        
# ------------------------ python code ends here

        